@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 ''' Location routines'''
 
+from __future__ import with_statement
 import pyficache, linecache, tempfile
 from import_relative import import_relative, get_srcdir
-import pydbgr.lib
 Mstack = import_relative('stack', '..lib', 'pydbgr')
 
 def format_location(proc_obj):
