@@ -41,7 +41,7 @@ Mmisc      = import_relative('misc', '.', package)
 __title__ = package
 
 # VERSION.py sets variable VERSION.
-execfile(os.path.join(get_srcdir(), 'VERSION.py'))
+exec(compile(open(os.path.join(get_srcdir(), 'VERSION.py')).read(), os.path.join(get_srcdir(), 'VERSION.py'), 'exec'))
 __version__ = VERSION
 
 def process_options(debugger_name, pkg_version, sys_argv, option_list=None):
@@ -62,15 +62,15 @@ def process_options(debugger_name, pkg_version, sys_argv, option_list=None):
                              version="%%prog version %s" % pkg_version)
 
     optparser.add_option("-X", "--trace", dest="linetrace",
-                         action="store_true", default=False, 
+                         action="store_true", default=False,
                          help="Show lines before executing them. " +
                          "This option also sets --batch")
     optparser.add_option("-F", "--fntrace", dest="fntrace",
-                         action="store_true", default=False, 
+                         action="store_true", default=False,
                          help="Show functions before executing them. " +
                          "This option also sets --batch")
     optparser.add_option("--basename", dest="basename",
-                         action="store_true", default=False, 
+                         action="store_true", default=False,
                          help="Filenames strip off basename, (e.g. for regression tests)"
                          )
 #     optparser.add_option("--batch", dest="noninteractive",
@@ -90,7 +90,7 @@ def process_options(debugger_name, pkg_version, sys_argv, option_list=None):
                          action="store_true", default=False, 
                          help="Debug the debugger")
     optparser.add_option("--different", dest="different",
-                         action="store_true", default=True, 
+                         action="store_true", default=True,
                          help="Consecutive stops should have different positions")
 #     optparser.add_option("--error", dest="errors", metavar='FILE',
 #                          action="store", type='string',
@@ -100,9 +100,9 @@ def process_options(debugger_name, pkg_version, sys_argv, option_list=None):
                          help="list of debugger commands to " +
                          "execute. Separate the commands with ;;")
 
-    optparser.add_option("--highlight", dest="highlight", 
+    optparser.add_option("--highlight", dest="highlight",
                          action="store", type='string', metavar='{light|dark|plain}',
-                         default='light', 
+                         default='light',
                          help="Use syntax and terminal highlight output. 'plain' is no highlight")
     optparser.add_option("--private", dest="private",
                          action='store_true', default=False,
@@ -117,7 +117,7 @@ def process_options(debugger_name, pkg_version, sys_argv, option_list=None):
                          help="Don't enter debugger on an uncaught (fatal) exception")
 
     optparser.add_option("-n", "--nx", dest="noexecute",
-                         action="store_true", default=False, 
+                         action="store_true", default=False,
                          help="Don't execute commands found in any " +
                          "initialization files")
     optparser.add_option("-o", "--output", dest="output", metavar='FILE',
@@ -132,7 +132,7 @@ def process_options(debugger_name, pkg_version, sys_argv, option_list=None):
                          action='store_true',
                          help="Out-of-process server connection mode")
     optparser.add_option("--sigcheck", dest="sigcheck",
-                         action="store_true", default=False, 
+                         action="store_true", default=False,
                          help="Set to watch for signal handler changes")
     optparser.add_option("-t", "--target", dest="target",
                          help="Specify a target to connect to. Arguments" \
@@ -198,15 +198,16 @@ def process_options(debugger_name, pkg_version, sys_argv, option_list=None):
         pass
 
     if opts.output:
-        try: 
+        try:
             dbg_opts['output'] = Moutput.DebuggerUserOutput(opts.output)
-        except IOError, (errno, strerror):
-            print "I/O in opening debugger output file %s" % opts.output
-            print "error(%s): %s" % (errno, strerror)
+        except IOError as xxx_todo_changeme:
+            (errno, strerror) = xxx_todo_changeme.args
+            print("I/O in opening debugger output file %s" % opts.output)
+            print("error(%s): %s" % (errno, strerror))
         except:
-            print "Unexpected error in opening debugger output file %s" % \
-                  opts.output
-            print sys.exc_info()[0]
+            print("Unexpected error in opening debugger output file %s" % \
+                  opts.output)
+            print(sys.exc_info()[0])
             sys.exit(2)
             pass
         pass
@@ -229,11 +230,11 @@ def _postprocess_options(dbg, opts):
     print_events = []
     if opts.fntrace:   print_events = ['c_call', 'c_return', 'call', 'return']
     if opts.linetrace: print_events += ['line']
-    if len(print_events): 
+    if len(print_events):
         dbg.settings['printset'] = frozenset(print_events)
         pass
 
-    for setting in ('annotate', 'basename', 'different',): 
+    for setting in ('annotate', 'basename', 'different',):
         dbg.settings[setting] = getattr(opts, setting)
         pass
 
@@ -252,7 +253,7 @@ def _postprocess_options(dbg, opts):
         pass
 
 #     if opts.errors:
-#         try: 
+#         try:
 #             dbg.stderr = open(opts.errors, 'w')
 #         except IOError, (errno, strerror):
 #             print "I/O in opening debugger output file %s" % opts.errors
@@ -271,8 +272,9 @@ def _postprocess_options(dbg, opts):
     if opts.post_mortem:
         Mapi.debugger_on_post_mortem()
         pass
-    
-    return 
+
+
+    return
 
 def main(dbg=None, sys_argv=list(sys.argv)):
     """Routine which gets run if we were invoked directly"""
@@ -280,9 +282,9 @@ def main(dbg=None, sys_argv=list(sys.argv)):
 
     # Save the original just for use in the restart that works via exec.
     orig_sys_argv = list(sys_argv)
-    opts, dbg_opts, sys_argv  = process_options(__title__, __version__, 
+    opts, dbg_opts, sys_argv  = process_options(__title__, __version__,
                                                 sys_argv)
-    dbg_opts['orig_sys_argv'] = sys_argv
+    dbg_opts['orig_sys_argv'] = orig_sys_argv
 
     if dbg is None:
         dbg = Mdebugger.Debugger(dbg_opts)
@@ -360,7 +362,7 @@ def main(dbg=None, sys_argv=list(sys.argv)):
             dbg.core.execution_status = 'Restart requested'
             if dbg.program_sys_argv:
                 sys.argv = list(dbg.program_sys_argv)
-                part1 = ('Restarting %s with arguments:' % 
+                part1 = ('Restarting %s with arguments:' %
                          dbg.core.filename(mainpyfile))
                 args  = ' '.join(dbg.program_sys_argv[1:])
                 dbg.intf[-1].msg(Mmisc.wrapped_lines(part1, args,
