@@ -4,7 +4,7 @@
 This code is a rewrite of the stock python bdb.Breakpoint"""
 
 __all__ = ["BreakpointManager", "Breakpoint"]
-import types, os.path
+import os.path
 
 class BreakpointManager:
     """Manages the list of Breakpoints.
@@ -20,7 +20,7 @@ class BreakpointManager:
         return
 
     def get_breakpoint(self, i):
-        if isinstance(i, bytes):
+        if isinstance(i, str):
             try:
                 i = int(i)
             except ValueError:
