@@ -13,6 +13,7 @@
 #
 #   You should have received a copy of the GNU General Public License
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+from __future__ import with_statement
 import inspect, linecache, os, sys, shlex, tempfile, traceback, types
 import pyficache
 from repr import Repr
@@ -223,7 +224,7 @@ def print_location(proc_obj):
 DEFAULT_PROC_OPTS = {
     # A list of debugger initialization files to read on first command
     # loop entry.  Often this something like [~/.pydbgrrc] which the
-    # front-end sets. 
+    # front-end sets.
     'initfile_list' : []
 }
 
@@ -410,7 +411,7 @@ class CommandProcessor(Mprocessor.Processor):
             exec(code, global_vars, local_vars)
         except:
             t, v = sys.exc_info()[:2]
-            if type(t) == types.StringType:
+            if type(t) == bytes:
                 exc_type_name = t
             else: exc_type_name = t.__name__
             self.errmsg('%s: %s' % (str(exc_type_name), str(v)))
@@ -695,11 +696,12 @@ class CommandProcessor(Mprocessor.Processor):
                         pass
                     if type(current_command) == types.ListType:
                         for x in current_command:
-                            if types.StringType != type(x):
-                                self.errmsg("macro %s should return a List " +
-                                            "of Strings. Has %s of type %s" %
-                                            (macro_cmd_name, x, type(x),
-                                             current_command))
+                            if bytes != type(x):
+                                self.errmsg(("macro %s should return a List " +
+                                             "of Strings. Has %s of type %s") %
+                                             (macro_cmd_name, x,
+                                              repr(current_command),
+                                              type(x)))
                                 return False
                             pass
 
@@ -707,12 +709,12 @@ class CommandProcessor(Mprocessor.Processor):
                         args =  first.split()
                         self.cmd_queue + [current_command[1:]]
                         current_command = first
-                    elif type(current_command) == types.StringType:
+                    elif type(current_command) == bytes:
                         args = current_command.split()
                     else:
-                        self.errmsg("macro %s should return a List " +
-                   "of Strings or a String. Got %s" % (macro_cmd_name,
-                                                       current_command))
+                        self.errmsg(("macro %s should return a List " +
+                                     "of Strings or a String. Got %s") %
+                                     (macro_cmd_name, repr(current_command)))
                         return False
                     pass
 
@@ -843,24 +845,36 @@ class CommandProcessor(Mprocessor.Processor):
             if mod_name in ('info_sub', 'set_sub', 'show_sub',):
                 pass
             import_name = "command." + mod_name
-            try:
+            if True:
+                # Sometimes we want this
                 command_mod = getattr(__import__(import_name), mod_name)
-            except:
-                print('Error importing %s: %s' % (mod_name, sys.exc_info()[0]))
-                continue
-                
-            classnames = [ tup[0] for tup in 
+            else:
+                # FIXME give more info like the above when desired
+                try:
+                    command_mod = getattr(__import__(import_name), mod_name)
+                except:
+                    print('Error importing %s: %s' %
+                          (mod_name, sys.exc_info()[0]))
+                    continue
+                pass
+
+            classnames = [ tup[0] for tup in
                            inspect.getmembers(command_mod, inspect.isclass)
                            if ('DebuggerCommand' != tup[0] and
                                tup[0].endswith('Command')) ]
             for classname in classnames:
                 eval_cmd = eval_cmd_template % classname
-                try:
+                if True:
                     instance = eval(eval_cmd)
                     cmd_instances.append(instance)
-                except:
-                    print('Error loading %s from %s: %s' %
-                          (classname, mod_name, sys.exc_info()[0]))
+                else:
+                    try:
+                        instance = eval(eval_cmd)
+                        cmd_instances.append(instance)
+                    except:
+                        print('Error loading %s from %s: %s' %
+                              (classname, mod_name, sys.exc_info()[0]))
+                        pass
                     pass
                 pass
             pass
