@@ -163,7 +163,7 @@ class SubcommandMgr(Mbase_cmd.DebuggerCommand):
             # We were given cmd without a subcommand; cmd is something
             # like "show", "info" or "set". Generally this means list
             # all of the subcommands.
-            self.msg("List of %s commands (with minimum abbreviation in "
+            self.section("List of %s commands (with minimum abbreviation in "
                      "parenthesis):" % self.name)
             for subcmd_name in self.cmds.list():
                 # Some commands have lots of output.
