@@ -1,20 +1,15 @@
 # -*- coding: utf-8 -*-
 #   Copyright (C) 2009, 2013 Rocky Bernstein
 #
-#    This program is free software; you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
+#  This program is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
 #
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-#    02110-1301 USA.
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
 import os
 from import_relative import import_relative
 
@@ -72,11 +67,11 @@ if __name__ == '__main__':
             cp.stack, cp.curindex = Mcmdproc.get_stack(cp.curframe, None, None,
                                                        cp)
             command.run(['down'])
-            print '-' * 10
+            print('-' * 10)
             command.run(['down', '1'])
-            print '-' * 10
+            print('-' * 10)
             command.run(['down', '-1'])
-            print '-' * 10
+            print('-' * 10)
         else:
             nest_me(cp, command, i+1)
         return
