@@ -17,8 +17,8 @@
 from pyficache import highlight_string
 from import_relative import *
 # Our local modules
-import_relative('processor', '....', 'pydbgr')
-Mbase_subcmd  = import_relative('base_subcmd', '..', 'pydbgr')
+import_relative('processor', '....')
+Mbase_subcmd  = import_relative('base_subcmd', '..')
 
 class InfoMacro(Mbase_subcmd.DebuggerSubcommand):
   """**macro**
@@ -41,7 +41,7 @@ In the last form the only definitions of the given macro names is shown."""
   def run(self, args):
     if len(args) > 0: 
       if len(args) == 1 and '*' == args[0]:
-        macro_names = self.proc.macros.keys()
+        macro_names = list(self.proc.macros.keys())
       else:
         macro_names = args
         pass
@@ -60,19 +60,21 @@ In the last form the only definitions of the given macro names is shown."""
           self.errmsg('%s is not a defined macro' % macro_name)
           pass
         pass
-    elif 0 == len(self.proc.macros.keys()):
+    elif 0 == len(list(self.proc.macros.keys())):
       self.msg('No macros defined.')
     else:
-      self.msg(self.columnize_commands(self.proc.macros.keys()))
+      self.msg(self.columnize_commands(list(self.proc.macros.keys())))
       pass
     return
   pass
         
 if __name__ == '__main__':
-  # Demo it.
+    # Demo it.
     mock = import_relative('mock', '..')
     Minfo = import_relative('info', '..')
+    Mdebugger = import_relative('debugger', '....')
     d, cp = mock.dbg_setup()
-    # i = Minfo.InfoMacro(cp)
-    # cmd.run(cmd.prefix + %w(u foo))
+    i = Minfo.InfoCommand(cp)
+    sub = InfoMacro(i)
+    sub.run(["u"])
     pass
