@@ -1,20 +1,18 @@
 # -*- coding: utf-8 -*-
 #   Copyright (C) 2009, 2013 Rocky Bernstein
 #
-#    This program is free software; you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
+#  This program is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
 #
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
 #
-#    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-#    02110-1301 USA.
+#  You should have received a copy of the GNU General Public License
+#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import inspect, os
 from import_relative import import_relative
 
@@ -56,12 +54,12 @@ stopped or bottom-most execution frame frame."""
         try:
             # Set to change position, update our copy of the stack,
             # and display the new position
-            print self.proc.curframe.f_trace
+            print(self.proc.curframe.f_trace)
             self.proc.curframe.f_lineno = lineno
             self.proc.stack[self.proc.curindex] = \
                 self.proc.stack[self.proc.curindex][0], lineno
             Mcmdproc.print_location(self.proc)
-        except ValueError, e:
+        except ValueError as e:
             self.errmsg('jump failed: %s' % e)
         return False
     pass
@@ -70,7 +68,7 @@ if __name__ == '__main__':
     mock = import_relative('mock')
     d, cp = mock.dbg_setup()
     command = JumpCommand(cp)
-    print 'jump when not running: ', command.run(['jump', '1'])
+    print('jump when not running: ', command.run(['jump', '1']))
     command.core.execution_status = 'Running'
     cp.curframe = inspect.currentframe()
     cp.curindex = 0
