@@ -19,12 +19,14 @@
 from import_relative import *
 # Our local modules
 
-# FIXME: Until import_relative is fixed up...
-import_relative('processor', '....', 'pydbgr')
-
 Mbase_subcmd  = import_relative('base_subcmd', '..')
 
 class ShowAutoEval(Mbase_subcmd.DebuggerShowBoolSubcommand):
     "Show Python evaluation of unrecognized debugger commands"
     min_abbrev = len('autoe')
     pass
+
+if __name__ == '__main__':
+    Mhelper = import_relative('__demo_helper__', '.', 'pydbgr')
+    Mhelper.demo_run(ShowAutoEval)
+    pass
