@@ -19,11 +19,8 @@
 from import_relative import *
 # Our local modules
 
-# FIXME: Until import_relative is fixed up...
-import_relative('processor', '....', 'pydbgr')
-
 Mbase_subcmd  = import_relative('base_subcmd', '..', 'pydbgr')
-Mcmdfns       = import_relative('cmdfns', '..', 'pydbgr')
+Mcmdfns       = import_relative('cmdfns', '...', 'pydbgr')
 class ShowWidth(Mbase_subcmd.DebuggerSubcommand):
     "Show the number of characters the debugger thinks are in a line"
 
