@@ -1,26 +1,23 @@
 # -*- coding: utf-8 -*-
 #   Copyright (C) 2009, 2013 Rocky Bernstein
 #
-#    This program is free software; you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
+#  This program is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
 #
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
 #
-#    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-#    02110-1301 USA.
+#  You should have received a copy of the GNU General Public License
+#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import os, sys
 
 # Our local modules
 from import_relative import import_relative
 
-import_relative('lib', '...', 'pydbgr')
 Mbase_cmd  = import_relative('base_cmd', top_name='pydbgr')
 Mcmdfns    = import_relative('cmdfns', '..', 'pydbgr')
 Mfile      = import_relative('file', '...lib', 'pydbgr')
@@ -62,7 +59,7 @@ See also `break`.
     def run(self, args):
         func, filename, lineno, condition = Mcmdbreak.parse_break_cmd(self,
                                                                    args[1:])
-        Mbreak.set_break(self, func, filename, lineno, condition, True, args)
+        Mcmdbreak.set_break(self, func, filename, lineno, condition, True, args)
         return 
 
 if __name__ == '__main__':
@@ -72,18 +69,18 @@ if __name__ == '__main__':
     command.proc.frame = sys._getframe()
     command.proc.setup()
 
-    print Mbreak.parse_break_cmd(command, [])
-    print Mbreak.parse_break_cmd(command, ['10'])
-    print Mbreak.parse_break_cmd(command, [__file__ + ':10'])
+    print(Mcmdbreak.parse_break_cmd(command, []))
+    print(Mcmdbreak.parse_break_cmd(command, ['10']))
+    print(Mcmdbreak.parse_break_cmd(command, [__file__ + ':10']))
     def foo():
         return 'bar'
-    print Mbreak.parse_break_cmd(command, ['foo'])
-    print Mbreak.parse_break_cmd(command, ['os.path'])
-    print Mbreak.parse_break_cmd(command, ['os.path', '5+1'])
-    print Mbreak.parse_break_cmd(command, ['os.path.join'])
-    print Mbreak.parse_break_cmd(command, ['if', 'True'])
-    print Mbreak.parse_break_cmd(command, ['foo', 'if', 'True'])
-    print Mbreak.parse_break_cmd(command, ['os.path:10', 'if', 'True'])
+    print(Mcmdbreak.parse_break_cmd(command, ['foo']))
+    print(Mcmdbreak.parse_break_cmd(command, ['os.path']))
+    print(Mcmdbreak.parse_break_cmd(command, ['os.path', '5+1']))
+    print(Mcmdbreak.parse_break_cmd(command, ['os.path.join']))
+    print(Mcmdbreak.parse_break_cmd(command, ['if', 'True']))
+    print(Mcmdbreak.parse_break_cmd(command, ['foo', 'if', 'True']))
+    print(Mcmdbreak.parse_break_cmd(command, ['os.path:10', 'if', 'True']))
     command.run(['tbreak'])
     command.run(['tbreak', 'command.run'])
     command.run(['tbreak', '10'])
