@@ -1,8 +1,8 @@
-import os, sys
-from import_relative import *
+import sys
+from import_relative import import_relative
 
-Mdebugger    = import_relative('debugger', '...pydbgr', 'pydbgr')
-Mstringarray = import_relative('io.stringarray', '...pydbgr')
+Mdebugger    = import_relative('debugger', '...pydbgr')
+Mstringarray = import_relative('io.stringarray', '...pydbgr', 'pydbgr')
 
 def strarray_setup(debugger_cmds):
     ''' Common setup to create a debugger with stringio attached '''
@@ -39,7 +39,7 @@ def filter_line_cmd(a):
     return a3
 
 def get_lineno():
-    '''Return the caller's line number'''
+    """Return the caller's line number"""
     caller = sys._getframe(1)
     return caller.f_lineno
 
@@ -48,17 +48,17 @@ def compare_output(obj, right, d, debugger_cmds):
     if got != right:
         for i in range(len(got)):
             if i < len(right) and got[i] != right[i]:
-                print "! ", got[i]
+                print("! ", got[i])
             else:
-                print "  ", got[i]
+                print("  ", got[i])
                 pass
             pass
-        print '-' * 10
+        print('-' * 10)
         for i in range(len(right)):
             if i < len(got) and got[i] != right[i]:
-                print "! ", right[i]
+                print("! ", right[i])
             else:
-                print "  ", right[i]
+                print("  ", right[i])
                 pass
             pass
         pass
@@ -67,5 +67,5 @@ def compare_output(obj, right, d, debugger_cmds):
 
 # Demo it
 if __name__=='__main__':
-    print get_lineno()
+    print(get_lineno())
     pass
