@@ -1,20 +1,20 @@
 #!/usr/bin/env python
-'Unit test for pydbgr.io.tcp*'
+'Unit test for pydbgr.io.fifo*'
 import os
 if hasattr(os, 'mkfifo'):
 
-    import inspect, sys, unittest
+    import unittest
 
-    from import_relative import *
-    Mserver = import_relative('io.fifoserver', '...pydbgr')
-    Mclient = import_relative('io.fifoclient', '...pydbgr')
+    from import_relative import import_relative
+    Mserver = import_relative('pydbgr.io.fifoserver', '...')
+    Mclient = import_relative('pydbgr.io.fifoclient', '...')
 
     class TestFIFO(unittest.TestCase):
         """Tests FIFOServer and FIFOClient"""
 
         def test_client_server(self):
-            server = Mserver.FIFOServer(opts={'open': True})
-            client = Mclient.FIFOClient(opts={'open': os.getpid()})
+            Mserver.FIFOServer(opts={'open': True})
+            Mclient.FIFOClient(opts={'open': os.getpid()})
             self.assertTrue(True, 'FIXME: need to add a test here.')
             # FIXME need to use threading or forking
     #         for line in ['one', 'two', 'three']: 
