@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 'Unit test for pydbgr.processor.command.help'
-import inspect, os, sys, unittest, types
+import unittest
 
-from import_relative import *
+from import_relative import import_relative
 
 # FIXME: until import_relative is fixed
 import_relative('pydbgr', '...', 'pydbgr')
@@ -10,9 +10,6 @@ import_relative('pydbgr', '...', 'pydbgr')
 Mhelp    = import_relative('processor.command.help', '...pydbgr', 'pydbgr')
 Mcmdproc = import_relative('processor.cmdproc', '...pydbgr', 'pydbgr')
 
-from cmdhelper import dbg_setup
-import signal
-
 Mmock = import_relative('processor.command.mock', '...pydbgr')
 
 class TestHelp(unittest.TestCase):
@@ -67,8 +64,8 @@ class TestHelp(unittest.TestCase):
 
     def test_short_help(self):
         """Test each command has some sort of short help"""
-        for cmd in self.cp.commands.values():
-            self.assertEqual(types.StringType, type(cmd.short_help))
+        for cmd in list(self.cp.commands.values()):
+            self.assertEqual(str, type(cmd.short_help))
             pass
         return
 
