@@ -1,6 +1,6 @@
 #!/usr/bin/env python
-'Unit test for pydbgr.clifns'
-import inspect, os, sys, unittest
+'Unit test for debugger info file'
+import inspect, unittest
 from import_relative import import_relative
 
 debugger  = import_relative('debugger', '...pydbgr', 'pydbgr')
@@ -13,8 +13,19 @@ from cmdhelper import dbg_setup
 
 class TestInfoFile(unittest.TestCase):
 
-    def setUp(self):
+    # FIXME: put in a more common place
+    # Possibly fix up Mock to include this
+    def setup_io(self, command):
+        self.clear_output()
+        command.msg = self.msg
+        command.errmsg = self.errmsg
+        command.msg_nocr = self.msg_nocr
+        return
+
+    def clear_output(self):
         self.msgs = []
+        self.errmsgs = []
+        self.last_was_newline = True
         return
 
     def msg_nocr(self, msg):
@@ -28,18 +39,24 @@ class TestInfoFile(unittest.TestCase):
         self.msgs += [msg]
         return
 
+    def errmsg(self, msg):
+        self.errmsgs.append(msg)
+        pass
+
     def test_info_file(self):
         d = Mdebugger.Debugger()
         d, cp = dbg_setup(d)
         command = Minfo.InfoCommand(cp, 'info')
+
         sub = MinfoFile.InfoFile(command)
+        self.setup_io(sub)
         sub.run([])
         self.assertEqual([], self.msgs)
         cp.curframe = inspect.currentframe()
         for width in (80, 200):
             # sub.settings['width'] = width
             sub.run(['test-info-file.py', 'lines'])
-            print sub.run([])
+            sub.run([])
             pass
         pass
         
