@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 'Unit test for pydbgr.processor.subcmd'
-import inspect, os, sys, unittest
-from import_relative import *
+import unittest
+from import_relative import import_relative
 
 Msubcmd   = import_relative('processor.subcmd', '...pydbgr')
 Mbase_cmd = import_relative('processor.command.base_cmd', '...pydbgr')
@@ -19,7 +19,7 @@ class MyCommand(Mbase_cmd.DebuggerCommand):
         self.name  = 'test'
         return
     
-    def run(self, args): print 'test command run'
+    def run(self, args): print('test command run')
     pass
     
 class MySubcommand:
@@ -32,7 +32,7 @@ class MySubcommand:
     short_help = 'This is short help for test testing'
     min_abbrev = 4
     in_list    = True
-    def run(self, args): print 'test testing run'
+    def run(self, args): print('test testing run')
     pass
 
 class TestSubcommand(unittest.TestCase):
